
# ColoreRegioni
Web-scraping del [sito del governo italiano](http://www.governo.it/it/articolo/domande-frequenti-sulle-misure-adottate-dal-governo/15638?gclid=CjwKCAiAwrf-BRA9EiwAUWwKXicC1bzopYynHP9pvRxHUza7Ar4dte9hWHi55Uj4xfuAHanOCf7a1BoCTggQAvD_BwE) per la classificazione delle misure restrittive regionali.

## Usage
La classe ColoreRegioni() restituisce:
```
full_dict=ColoreRegioni().colori_emoji
dict_only_colors=ColoreRegioni().colori
nome_regioni=ColoreRegioni().denominazioni
```
<p align="center">
  <img src="https://github.com/MCilento93/ColoreRegioni/blob/main/images/full_dict.png" width="450px">
</p>

# License
This repository is licensed under [MIT](LICENSE) (c) 2019 GitHub, Inc.
